from osbot_fast_api.api.Fast_API                                             import Fast_API

class Graphviz_MGraph_AI___Fast_API(Fast_API):
    base_path  : str  = '/'
    enable_cors: bool = True

    # def setup_routes(self):
    #     self.add_routes(Routes__Info      )
    #     self.add_routes(Routes__Web_Root  )
    #     self.add_routes(Routes__Graphviz  )
    #     self.add_routes(Routes__Matplotlib)
    #     self.add_routes(Routes__Browser   )
    #     self.add_routes(Routes__Debug     )


